@@ -18,14 +18,18 @@
 #ifndef GPARTED_DIALOGFEATURES_H
 #define GPARTED_DIALOGFEATURES_H
 
-#include "Utils.h"
+
+#include "FileSystem.h"
 
 #include <gtkmm/dialog.h>
 #include <gtkmm/frame.h>
 #include <gtkmm/treeview.h>
 #include <gtkmm/liststore.h>
 #include <gtkmm/scrolledwindow.h>
-#include <gtkmm/image.h>
+#include <glibmm/ustring.h>
+#include <gdkmm/pixbuf.h>
+#include <vector>
+
 
 namespace GParted
 {
@@ -36,10 +40,10 @@ public:
 	DialogFeatures() ;
 	~DialogFeatures() ;
 
-	void load_filesystems( const std::vector<FS> & FILESYSTEMS ) ;
-	
+	void load_filesystems(const std::vector<FS>& fss);
+
 private:
-	void show_filesystem( const FS & fs ) ;
+	void load_one_filesystem(const FS& fs);
 
 	Gtk::Frame legend_frame ;
 	Gtk::TreeView treeview_filesystems;
