@@ -20,7 +20,9 @@
 
 #include "i18n.h"
 #include "Utils.h"
+#include "Device.h"
 #include "Operation.h"
+#include "Partition.h"
 
 #include <gtkmm/dialog.h>
 #include <gtkmm/progressbar.h>
@@ -28,8 +30,9 @@
 #include <gtkmm/treestore.h>
 #include <gtkmm/scrolledwindow.h>
 #include <gtkmm/expander.h>
-
 #include <fstream>
+#include <vector>
+
 
 namespace GParted
 {
@@ -37,12 +40,11 @@ namespace GParted
 class Dialog_Progress : public Gtk::Dialog
 {
 public:
-	Dialog_Progress( const std::vector<Operation *> & operations ) ;
+	Dialog_Progress(const std::vector<Device>& devices, const std::vector<Operation *>& operations);
 	~Dialog_Progress();
-	
+
 	sigc::signal< bool, Operation * > signal_apply_operation ;
-	sigc::signal< Glib::ustring > signal_get_libparted_version ;
-		
+
 private:
 	void on_signal_update( const OperationDetail & operationdetail ) ;
 	void update_gui_elements() ;
@@ -50,8 +52,10 @@ private:
 	void on_cell_data_description( Gtk::CellRenderer * renderer, const Gtk::TreeModel::iterator & iter) ;
 	void on_cancel() ;
 	void on_save() ;
-	void echo_operation_details( const OperationDetail & operation_detail, std::ofstream & out ) ;
-	
+	void write_device_details(const Device& device, std::ofstream& out);
+	void write_partition_details(const Partition& partition, std::ofstream& out);
+	void write_operation_details(const OperationDetail& operation_detail, std::ofstream& out);
+
 	void on_response( int response_id ) ;
 	bool on_delete_event( GdkEventAny * event ) ;
 	bool pulsebar_pulse();
@@ -87,12 +91,14 @@ private:
 		} 
 	};
 	treeview_operations_Columns treeview_operations_columns;
-	
+
+	const std::vector<Device>& m_devices;
 	std::vector<Operation *> operations ;
 	Glib::ustring progress_text;
 	bool succes, cancel;
 	double fraction ;
-	unsigned int t, warnings ;
+	unsigned int m_curr_op;
+	unsigned int warnings;
 	sigc::connection pulsetimer;
 	Glib::ustring label_current_sub_text ;
 	unsigned int cancel_countdown;
