@@ -65,7 +65,7 @@ private:
 	int spreadout_leftover_px( std::vector<visual_partition> & visual_partitions, int pixels ) ;
 	
 	//overridden signalhandlers
-	bool on_expose_event( GdkEventExpose * event ) ;
+	bool on_draw(const Cairo::RefPtr<Cairo::Context>& cr);
 	bool on_button_press_event( GdkEventButton * event ) ;
 	void on_size_allocate( Gtk::Allocation & allocation ) ;
 
@@ -81,7 +81,7 @@ private:
 		int y_usage_start, usage_height ;
 		int x_text, y_text ;
 
-		Gdk::Color color ;
+		Gdk::RGBA color;
 		Glib::RefPtr<Pango::Layout> pango_layout;
 
 		// Pointer to real partition.  (Alias to element in Win_GParted::display_partitions[] vector).
@@ -115,7 +115,10 @@ private:
 	const visual_partition * selected_vp ;
 	int TOT_SEP, MIN_SIZE ;
 
-	Gdk::Color color_used, color_unused, color_unallocated, color_text;
+	Gdk::RGBA color_used;
+	Gdk::RGBA color_unused;
+	Gdk::RGBA color_unallocated;
+	Gdk::RGBA color_text;
 };
 
 } //GParted
