@@ -17,7 +17,9 @@
 #ifndef GPARTED_OPERATIONCOPY_H
 #define GPARTED_OPERATIONCOPY_H
 
-#include "../include/Operation.h"
+#include "Operation.h"
+#include "Partition.h"
+#include "PartitionVector.h"
 
 namespace GParted
 {
@@ -29,15 +31,22 @@ public:
 		       const Partition & partition_orig,
 		       const Partition & partition_new,
 		       const Partition & partition_copied ) ;
-	
-	void apply_to_visual( std::vector<Partition> & partitions ) ;
+	virtual ~OperationCopy();
 
-	Partition partition_copied ;
+	Partition & get_partition_copied();
+	const Partition & get_partition_copied() const;
+
+	void apply_to_visual( PartitionVector & partitions );
 
 private:
+	OperationCopy( const OperationCopy & src );              // Not implemented copy constructor
+	OperationCopy & operator=( const OperationCopy & rhs );  // Not implemented copy assignment operator
+
 	void create_description() ;
 	bool merge_operations( const Operation & candidate );
-} ;
+
+	Partition * partition_copied;
+};
 
 } //GParted
 
