@@ -30,12 +30,12 @@ namespace GParted
 {
 
 enum OperationDetailStatus {
-	STATUS_NONE	= 0, 
-	STATUS_EXECUTE	= 1,
-	STATUS_SUCCES	= 2,
-	STATUS_ERROR	= 3,
-	STATUS_INFO	= 4,
-	STATUS_N_A	= 5
+	STATUS_NONE    = 0,
+	STATUS_EXECUTE = 1,
+	STATUS_SUCCESS = 2,
+	STATUS_ERROR   = 3,
+	STATUS_INFO    = 4,
+	STATUS_WARNING = 5
 };
 
 enum Font {
@@ -60,6 +60,7 @@ public:
 	void set_description( const Glib::ustring & description, Font font = FONT_NORMAL ) ;
 	Glib::ustring get_description() const ;
 	void set_status( OperationDetailStatus status ) ;
+	void set_success_and_capture_errors( bool success );
 	OperationDetailStatus get_status() const ;
 	void set_treepath( const Glib::ustring & treepath ) ;
 	Glib::ustring get_treepath() const ;
@@ -74,9 +75,11 @@ public:
 
 	sigc::signal< void, const OperationDetail & > signal_update ;
 	sigc::signal< void, bool > signal_cancel;
+	sigc::signal< void, OperationDetail &, bool > signal_capture_errors;
 	char cancelflag;
 
 private:
+	void add_child_implement( const OperationDetail & operationdetail );
 	void on_update( const OperationDetail & operationdetail ) ;
 	void cancel( bool force );
 	ProgressBar & get_progressbar() const;
@@ -88,6 +91,9 @@ private:
 	
 	std::vector<OperationDetail*> sub_details;
 	std::time_t time_start, time_elapsed ;
+	bool no_more_children;  // Disallow adding more children to ensure captured errors
+	                        // remain the last child of this operation detail.
+
 	sigc::connection cancelconnection;
 };
 
