@@ -17,8 +17,8 @@
 #ifndef GPARTED_TREEVIEW_DETAIL_H
 #define GPARTED_TREEVIEW_DETAIL_H
 
-#include "../include/Partition.h"
-#include "../include/PartitionVector.h"
+#include "Partition.h"
+#include "PartitionVector.h"
 
 #include <gtkmm/treeview.h>
 #include <gtkmm/treestore.h>
@@ -47,13 +47,17 @@ public:
 
 private:
 	void load_partitions( const PartitionVector & partitions,
-	                      bool & mountpoints,
-	                      bool & labels,
-	                      bool & names,
+	                      bool & show_names,
+	                      bool & show_mountpoints,
+	                      bool & show_labels,
 	                      const Gtk::TreeRow & parent_row = Gtk::TreeRow() );
 	bool set_selected( Gtk::TreeModel::Children rows,
 	                   const Partition * partition_ptr, bool inside_extended = false );
-	void create_row( const Gtk::TreeRow & treerow, const Partition & partition );
+	void create_row( const Gtk::TreeRow & treerow,
+	                 const Partition & partition,
+	                 bool & show_names,
+	                 bool & show_mountpoints,
+	                 bool & show_labels );
 
 	//(overridden) signals
 	bool on_button_press_event( GdkEventButton * event );
