@@ -27,8 +27,10 @@
 #include "i18n.h"
 
 #include <gtkmm/label.h>
+#include <gtkmm/image.h>
+#include <gdkmm/pixbuf.h>
 #include <glibmm/ustring.h>
-
+#include <glibmm/spawn.h>
 #include <iostream>
 #include <ctime>
 #include <vector>
@@ -126,8 +128,13 @@ public:
 	                            , bool use_markup = true
 	                            , bool wrap = false
 	                            , bool selectable = false
-	                            , float yalign = 0.5 /* ALIGN_CENTER */
+	                            , Gtk::Align valign = Gtk::ALIGN_CENTER
 	                            ) ;
+	static Gtk::Image* mk_image(const Gtk::StockID& stock_id, Gtk::IconSize icon_size);
+	static Glib::RefPtr<Gdk::Pixbuf> mk_pixbuf(Gtk::Widget& widget,
+	                                           const Gtk::StockID& stock_id,
+	                                           Gtk::IconSize icon_size);
+	static Glib::ustring get_stock_label(const Gtk::StockID& stock_id);
 	static Glib::ustring num_to_str( Sector number ) ;
 	static Glib::ustring get_color( FSType filesystem );
 	static Glib::RefPtr<Gdk::Pixbuf> get_color_as_pixbuf( FSType filesystem, int width, int height );
