@@ -17,64 +17,72 @@
 
 #include "Dialog_Base_Partition.h"
 #include "Partition.h"
+#include "Utils.h"
+
+#include <glibmm/ustring.h>
+
 
 namespace GParted
 {
 	
 Dialog_Base_Partition::Dialog_Base_Partition()
 {
-	this ->set_has_separator( false ) ;
 	frame_resizer_base = NULL;
 	GRIP = false ;
 	this ->fixed_start = false ;
 	this ->set_resizable( false );
 	ORIG_BEFORE = ORIG_SIZE = ORIG_AFTER = -1 ;
 	MIN_SPACE_BEFORE_MB = -1 ;
-	
-	//pack resizer hbox
-	this ->get_vbox() ->pack_start( hbox_resizer, Gtk::PACK_SHRINK );
-	
-	//add label_minmax
-	this ->get_vbox() ->pack_start( label_minmax, Gtk::PACK_SHRINK );
-	
-	//pack hbox_main
-	this ->get_vbox() ->pack_start( hbox_main, Gtk::PACK_SHRINK );
 
-	//put the vbox with resizer stuff (cool widget and spinbuttons) in the hbox_main
+	// Pack resizer hbox
+	hbox_resizer.set_orientation(Gtk::ORIENTATION_HORIZONTAL);
+	this->get_content_area()->pack_start(hbox_resizer, Gtk::PACK_SHRINK);
+
+	// Add label_minmax
+	this->get_content_area()->pack_start(label_minmax, Gtk::PACK_SHRINK);
+
+	// Pack hbox_main
+	hbox_main.set_orientation(Gtk::ORIENTATION_HORIZONTAL);
+	this->get_content_area()->pack_start(hbox_main, Gtk::PACK_SHRINK);
+
+	// Put the vbox with resizer stuff (cool widget and spinbuttons) in the hbox_main
+	vbox_resize_move.set_orientation(Gtk::ORIENTATION_VERTICAL);
 	hbox_main .pack_start( vbox_resize_move, Gtk::PACK_EXPAND_PADDING );
-	
-	//fill table
-	table_resize .set_border_width( 5 ) ;
-	table_resize .set_row_spacings( 5 ) ;
-	hbox_table.pack_start( table_resize, Gtk::PACK_EXPAND_PADDING ) ;
-	
-	hbox_table .set_border_width( 5 ) ;
-	vbox_resize_move .pack_start( hbox_table, Gtk::PACK_SHRINK );
-	
-	//add spinbutton_before
-	table_resize .attach(
-		* Utils::mk_label( static_cast<Glib::ustring>( _( "Free space preceding (MiB):") ) + " \t" ),
-		0, 1, 0, 1,
-		Gtk::SHRINK );
-		
+
+	// Fill grid
+	grid_resize.set_border_width(5);
+	grid_resize.set_row_spacing(5);
+	hbox_grid.set_orientation(Gtk::ORIENTATION_HORIZONTAL);
+	hbox_grid.pack_start(grid_resize, Gtk::PACK_EXPAND_PADDING);
+
+	hbox_grid.set_border_width(5);
+	vbox_resize_move.pack_start(hbox_grid, Gtk::PACK_SHRINK);
+
+	// Add spinbutton_before
+	grid_resize.attach(*Utils::mk_label(Glib::ustring(_("Free space preceding (MiB):")) + " \t"),
+	                   0, 0, 1, 1);
+
 	spinbutton_before .set_numeric( true );
 	spinbutton_before .set_increments( 1, 100 );
-	table_resize.attach( spinbutton_before, 1, 2, 0, 1, Gtk::FILL );
-	
-	//add spinbutton_size
-	table_resize.attach( * Utils::mk_label( _( "New size (MiB):" ) ), 0, 1, 1, 2 );
+	spinbutton_before.set_width_chars(7);
+	grid_resize.attach(spinbutton_before, 1, 0, 1, 1);
+
+	// Add spinbutton_size
+	grid_resize.attach(*Utils::mk_label(_("New size (MiB):")), 0, 1, 1, 1);
 
 	spinbutton_size .set_numeric( true );
 	spinbutton_size .set_increments( 1, 100 );
-	table_resize.attach( spinbutton_size, 1, 2, 1, 2, Gtk::FILL );
-	
-	//add spinbutton_after
-	table_resize.attach( * Utils::mk_label( _( "Free space following (MiB):") ), 0, 1, 2, 3 ) ;
-	
+	spinbutton_size.set_width_chars(7);
+	grid_resize.attach(spinbutton_size, 1, 1, 1, 1);
+
+	// Add spinbutton_after
+	grid_resize.attach(*Utils::mk_label(_("Free space following (MiB):")), 0, 2, 1, 1);
+
 	spinbutton_after .set_numeric( true );
 	spinbutton_after .set_increments( 1, 100 );
-	table_resize.attach( spinbutton_after, 1, 2, 2, 3, Gtk::FILL );
-	
+	spinbutton_after.set_width_chars(7);
+	grid_resize.attach(spinbutton_after, 1, 2, 1, 1);
+
 	if ( ! fixed_start )
 		before_value = spinbutton_before .get_value() ;
 
@@ -94,10 +102,9 @@ Dialog_Base_Partition::Dialog_Base_Partition()
 		sigc::bind<SPINBUTTON>( 
 			sigc::mem_fun(*this, &Dialog_Base_Partition::on_spinbutton_value_changed), AFTER ) ) ;
 
-	//add alignment
+	// Add alignment
 	/* TO TRANSLATORS: used as label for a list of choices.  Align to: <combo box with choices> */
-	table_resize .attach( * Utils::mk_label( static_cast<Glib::ustring>( _("Align to:") ) + "\t" ),
-	                      0, 1, 3, 4, Gtk::FILL );
+	grid_resize.attach(*Utils::mk_label(Glib::ustring(_("Align to:")) + "\t"), 0, 3, 1, 1);
 
 	// Fill partition alignment combo
 	/* TO TRANSLATORS: Option for combo box "Align to:" */
@@ -109,7 +116,12 @@ Dialog_Base_Partition::Dialog_Base_Partition()
 
 	combo_alignment.set_active(ALIGN_MEBIBYTE);  // Default setting
 
-	table_resize.attach(combo_alignment, 1, 2, 3, 4, Gtk::FILL);
+	grid_resize.attach(combo_alignment, 1, 3, 1, 1);
+
+	// Set vexpand on all grid_resize child widgets
+	std::vector<Gtk::Widget*> children = grid_resize.get_children();
+	for (std::vector<Gtk::Widget*>::iterator it = children.begin(); it != children.end(); ++it)
+		(*it)->set_vexpand();
 
 	this->add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
 	this ->show_all_children() ;
@@ -246,8 +258,8 @@ void Dialog_Base_Partition::Set_Confirm_Button( CONFIRMBUTTON button_type )
 			break ;
 		case RESIZE_MOVE:
 			{
-				Gtk::Image* image_temp(manage(new Gtk::Image(Gtk::Stock::GOTO_LAST, Gtk::ICON_SIZE_BUTTON)));
-				Gtk::HBox* hbox_resize_move(manage(new Gtk::HBox()));
+				Gtk::Image* image_temp = Utils::mk_image(Gtk::Stock::GOTO_LAST, Gtk::ICON_SIZE_BUTTON);
+				Gtk::Box* hbox_resize_move(manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL)));
 
 				hbox_resize_move->pack_start(*image_temp, Gtk::PACK_EXPAND_PADDING);
 				hbox_resize_move->pack_start(*Utils::mk_label(fixed_start ? _("Resize") : _("Resize/Move")),
@@ -268,8 +280,8 @@ void Dialog_Base_Partition::Set_Confirm_Button( CONFIRMBUTTON button_type )
 
 void Dialog_Base_Partition::Set_MinMax_Text( Sector min, Sector max )
 {
-	Glib::ustring str_temp(String::ucompose( _("Minimum size: %1 MiB"), min ) + "\t\t");
-	str_temp += String::ucompose( _("Maximum size: %1 MiB"), max ) ;
+	Glib::ustring str_temp(Glib::ustring::compose( _("Minimum size: %1 MiB"), min ) + "\t\t");
+	str_temp += Glib::ustring::compose( _("Maximum size: %1 MiB"), max ) ;
 	label_minmax .set_text( str_temp ) ; 
 }
 
@@ -393,6 +405,10 @@ Dialog_Base_Partition::~Dialog_Base_Partition()
 	size_change_connection .disconnect() ;
 	after_change_connection .disconnect() ;
 	delete frame_resizer_base;
+
+	// Work around a Gtk issue fixed in 3.24.0.
+	// https://gitlab.gnome.org/GNOME/gtk/issues/125
+	hide();
 }
 
 } //GParted
