@@ -22,8 +22,10 @@
 #include "Utils.h"
 #include "btrfs.h"
 
+#include <glibmm/miscutils.h>
 #include <gtkmm/alignment.h>
 #include <gtkmm/viewport.h>
+#include <gtkmm/grid.h>
 #include <gdkmm/general.h>
 
 namespace GParted
@@ -31,7 +33,6 @@ namespace GParted
 
 Dialog_Partition_Info::Dialog_Partition_Info( const Partition & partition ) : partition( partition )
 {
-	this ->set_has_separator( false ) ;
 	// Set minimum dialog height so it fits on an 800x600 screen without too much
 	// whitespace (~500 px max for GNOME desktop).  Allow extra space if have any
 	// messages or for LVM2 PV or LUKS encryption.
@@ -43,15 +44,19 @@ Dialog_Partition_Info::Dialog_Partition_Info( const Partition & partition ) : pa
 		this ->set_size_request( -1, 370 ) ;	//Minimum 370 to avoid scrolling on Fedora 20
 
 	/*TO TRANSLATORS: dialogtitle, looks like Information about /dev/hda3 */
-	this ->set_title( String::ucompose( _("Information about %1"), partition .get_path() ) );
+	this ->set_title( Glib::ustring::compose( _("Information about %1"), partition .get_path() ) );
 
 	init_drawingarea() ;
 
-	//place info and optional messages in scrollable window
+	// Place info and optional messages in scrollable window
+	info_msg_vbox.set_orientation(Gtk::ORIENTATION_VERTICAL);
 	info_msg_vbox .set_border_width( 6 ) ;
 	info_scrolled .set_policy( Gtk::POLICY_NEVER, Gtk::POLICY_AUTOMATIC ) ;
+#if HAVE_SET_PROPAGATE_NATURAL_WIDTH
+	info_scrolled.set_propagate_natural_width(true);
+#endif
 	info_scrolled .add( info_msg_vbox ) ;
-	//As Gtk::VBox widget info_msg_vbox doesn't have a native scrolling capability a
+	//  As Gtk::Box widget info_msg_vbox doesn't have a native scrolling capability a
 	//  Gtk::Viewport is automatically created to contain it when it is added to the
 	//  Gtk::ScrolledWindow widget info_scrolled.  The Viewport widget is created with
 	//  shadow type GTK_SHADOW_IN by default.  Change to GTK_SHADOW_NONE.
@@ -61,7 +66,7 @@ Dialog_Partition_Info::Dialog_Partition_Info( const Partition & partition ) : pa
 	//horizontally center the information scrolled window to match partition graphic
 	Gtk::Alignment * center_widget = manage( new Gtk::Alignment(0.5, 0.5, 0.0, 1.0) ) ;
 	center_widget ->add( info_scrolled ) ;
-	this ->get_vbox() ->pack_start( *center_widget ) ;
+	this->get_content_area()->pack_start(*center_widget);
 
 	//add label for detail and fill with relevant info
 	Display_Info() ;
@@ -72,9 +77,9 @@ Dialog_Partition_Info::Dialog_Partition_Info( const Partition & partition ) : pa
 		frame = manage( new Gtk::Frame() );
 
 		{
-			Gtk::Image* image(manage(new Gtk::Image(Gtk::Stock::DIALOG_WARNING, Gtk::ICON_SIZE_BUTTON)));
+			Gtk::Image* image = Utils::mk_image(Gtk::Stock::DIALOG_WARNING, Gtk::ICON_SIZE_BUTTON);
 
-			hbox = manage(new Gtk::HBox());
+			hbox = manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL));
 			hbox->pack_start(*image, Gtk::PACK_SHRINK);
 		}
 
@@ -105,7 +110,7 @@ Dialog_Partition_Info::Dialog_Partition_Info( const Partition & partition ) : pa
 				concatenated_messages += "<i>" + messages[i].substr( 0, take ) + "</i>";
 			}
 		}
-		Gtk::VBox *vbox( manage( new Gtk::VBox() ) ) ;
+		Gtk::Box *vbox = manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL));
 		vbox ->set_border_width( 5 ) ;
 		vbox->pack_start( *Utils::mk_label( concatenated_messages, true, true, true ), Gtk::PACK_SHRINK );
 		frame ->add( *vbox ) ;
@@ -118,27 +123,16 @@ Dialog_Partition_Info::Dialog_Partition_Info( const Partition & partition ) : pa
 }
 
 
-bool Dialog_Partition_Info::drawingarea_on_expose( GdkEventExpose *ev )
+bool Dialog_Partition_Info::drawingarea_on_draw(const Cairo::RefPtr<Cairo::Context>& cr)
 {
-	Glib::RefPtr<Gdk::Window> window = drawingarea.get_window();
-	if (!window)
-		return true;
-
-	Cairo::RefPtr<Cairo::Context> cr = window->create_cairo_context();
-
-	// Clip to the area indicated by the expose event so that we only redraw
-	// the portion of the window that needs to be redrawn.
-	cr->rectangle(ev->area.x, ev->area.y, ev->area.width, ev->area.height);
-	cr->clip();
-
-	Gdk::Cairo::set_source_color(cr, color_partition);
+	Gdk::Cairo::set_source_rgba(cr, color_partition);
 	cr->rectangle(0, 0, 400, 60);
 	cr->fill();
 
 	if ( partition.filesystem != FS_UNALLOCATED )
 	{
 		// Used
-		Gdk::Cairo::set_source_color(cr, color_used);
+		Gdk::Cairo::set_source_rgba(cr, color_used);
 		cr->rectangle(BORDER,
 		              BORDER,
 		              used,
@@ -146,7 +140,7 @@ bool Dialog_Partition_Info::drawingarea_on_expose( GdkEventExpose *ev )
 		cr->fill();
 
 		// Unused
-		Gdk::Cairo::set_source_color(cr, color_unused);
+		Gdk::Cairo::set_source_rgba(cr, color_unused);
 		cr->rectangle(BORDER + used,
 		              BORDER,
 		              unused,
@@ -154,7 +148,7 @@ bool Dialog_Partition_Info::drawingarea_on_expose( GdkEventExpose *ev )
 		cr->fill();
 
 		// Unallocated
-		Gdk::Cairo::set_source_color(cr, color_unallocated);
+		Gdk::Cairo::set_source_rgba(cr, color_unallocated);
 		cr->rectangle(BORDER + used + unused,
 		              BORDER,
 		              unallocated,
@@ -163,7 +157,7 @@ bool Dialog_Partition_Info::drawingarea_on_expose( GdkEventExpose *ev )
 	}
 
 	// Text
-	Gdk::Cairo::set_source_color(cr, color_text);
+	Gdk::Cairo::set_source_rgba(cr, color_text);
 	cr->move_to(180, BORDER + 6);
 	pango_layout->show_in_cairo_context(cr);
 
@@ -173,18 +167,18 @@ bool Dialog_Partition_Info::drawingarea_on_expose( GdkEventExpose *ev )
 void Dialog_Partition_Info::init_drawingarea() 
 {
 	drawingarea .set_size_request( 400, 60 ) ;
-	drawingarea .signal_expose_event().connect( sigc::mem_fun(*this, &Dialog_Partition_Info::drawingarea_on_expose) ) ;
-	
+	drawingarea.signal_draw().connect(sigc::mem_fun(*this, &Dialog_Partition_Info::drawingarea_on_draw));
+
 	frame = manage( new Gtk::Frame() ) ;
 	frame ->add( drawingarea ) ;
 	
 	frame ->set_shadow_type( Gtk::SHADOW_ETCHED_OUT ) ;
 	frame ->set_border_width( 10 ) ;
-	hbox = manage( new Gtk::HBox() ) ;
+	hbox = manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL));
 	hbox ->pack_start( *frame, Gtk::PACK_EXPAND_PADDING ) ;
-	
-	this ->get_vbox() ->pack_start( *hbox, Gtk::PACK_SHRINK ) ;
-	
+
+	this->get_content_area()->pack_start(*hbox, Gtk::PACK_SHRINK);
+
 	//calculate proportional width of used, unused and unallocated
 	if (partition.type == TYPE_EXTENDED)
 	{
@@ -247,68 +241,53 @@ void Dialog_Partition_Info::Display_Info()
 		// file system is accessible.
 		filesystem_accessible = true;
 
-	//initialize table top and bottom row number attach trackers
-	int top = 0     , bottom = 1 ;      //Left field & value pairs
-	int topright = 0, bottomright = 1 ; //Right field & value pairs
+	Gtk::Grid *grid(Gtk::manage(new Gtk::Grid()));
 
-	Gtk::Table* table(manage(new Gtk::Table()));
+	grid->set_border_width(5);
+	grid->set_column_spacing(10);
+	info_msg_vbox.pack_start(*grid, Gtk::PACK_SHRINK);
 
-	table ->set_border_width( 5 ) ;
-	table ->set_col_spacings(10 ) ;
-	info_msg_vbox .pack_start( *table, Gtk::PACK_SHRINK ) ;
+	// FILE SYSTEM DETAIL SECTION
+	// File system headline
+	grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("File System")) + "</b>"), 0, 0, 6, 1);
 
-	//FILE SYSTEM DETAIL SECTION
-	//file system headline
-	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("File System") ) + "</b>" ),
-			0, 6,
-			top++, bottom++,
-			Gtk::FILL ) ;
+	// Initialize grid top attach tracker (left side of the grid)
+	int top = 1;
 
-	//use current left row tracker position as anchor for right
-	topright = top ;
-	bottomright = bottom ;
-
-	//Left field & value pair area
-	//file system
-	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("File system:") ) + "</b>" ),
-			1, 2,
-			top, bottom,
-			Gtk::FILL ) ;
+	// Left field & value pair area
+	// File system
+	grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("File system:")) + "</b>"), 1, top, 1, 1);
 	if ( filesystem_accessible )
 	{
-		table->attach( *Utils::mk_label( Utils::get_filesystem_string( filesystem_ptn.filesystem ), true, false, true ),
-		               2, 3, top, bottom, Gtk::FILL );
+		grid->attach(*Utils::mk_label(Utils::get_filesystem_string(filesystem_ptn.filesystem), true, false, true),
+		             2, top, 1, 1);
 	}
-	top++, bottom++;
+	top++;
 
 	//label
 	if ( filesystem_ptn.filesystem != FS_UNALLOCATED && filesystem_ptn.type != TYPE_EXTENDED )
 	{
-		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Label:") ) + "</b>"),
-				1, 2,
-				top, bottom,
-				Gtk::FILL) ;
+		grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("Label:")) + "</b>"),
+		             1, top, 1, 1);
 		if ( filesystem_accessible )
 		{
-			table->attach( *Utils::mk_label( filesystem_ptn.get_filesystem_label(), true, false, true ),
-			               2, 3, top, bottom, Gtk::FILL);
+			grid->attach(*Utils::mk_label(filesystem_ptn.get_filesystem_label(), true, false, true),
+			             2, top, 1, 1);
 		}
-		top++, bottom++;
+		top++;
 	}
 
 	// file system uuid
 	if ( filesystem_ptn.filesystem != FS_UNALLOCATED && filesystem_ptn.type != TYPE_EXTENDED )
 	{
-		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("UUID:") ) + "</b>"),
-				1, 2,
-				top, bottom,
-				Gtk::FILL) ;
+		grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("UUID:")) + "</b>"),
+		             1, top, 1, 1);
 		if ( filesystem_accessible )
 		{
-			table->attach( *Utils::mk_label( filesystem_ptn.uuid, true, false, true ),
-			               2, 3, top, bottom, Gtk::FILL);
+			grid->attach(*Utils::mk_label(filesystem_ptn.uuid, true, false, true),
+			             2, top, 1, 1);
 		}
-		top++, bottom++;
+		top++;
 	}
 
 	/* TO TRANSLATORS:   Open
@@ -325,9 +304,9 @@ void Dialog_Partition_Info::Display_Info()
 	{
 		//status
 		Glib::ustring str_temp ;
-		table->attach( *Utils::mk_label( "<b>" + Glib::ustring( _("Status:") ) + "</b>",
-		                                 true, false, false, 0.0 /* ALIGN_TOP */ ),
-		               1, 2, top, bottom, Gtk::FILL );
+		grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("Status:")) + "</b>",
+		                              true, false, false, Gtk::ALIGN_START),
+		             1, top, 1, 1);
 		if ( ! filesystem_accessible )
 		{
 			/* TO TRANSLATORS:   Not accessible (Encrypted)
@@ -366,7 +345,7 @@ void Dialog_Partition_Info::Display_Info()
 			}
 			else if ( filesystem_ptn.get_mountpoints().size() )
 			{
-				str_temp = String::ucompose(
+				str_temp = Glib::ustring::compose(
 						/* TO TRANSLATORS: looks like   Mounted on /mnt/mymountpoint */
 						_("Mounted on %1"),
 						Glib::build_path( ", ", filesystem_ptn.get_mountpoints() ) );
@@ -426,26 +405,26 @@ void Dialog_Partition_Info::Display_Info()
 			str_temp = _("Not mounted") ;
 		}
 
-		table->attach( *Utils::mk_label( str_temp, true, true, true ), 2, 3, top++, bottom++, Gtk::FILL );
+		grid->attach(*Utils::mk_label(str_temp, true, true, true), 2, top++, 1, 1);
 	}
 
 	//Optional, LVM2 Volume Group name
 	if ( filesystem_ptn.filesystem == FS_LVM2_PV )
 	{
-		//Volume Group
-		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Volume Group:") ) + "</b>"),
-		                1, 2, top, bottom, Gtk::FILL ) ;
-		table ->attach( * Utils::mk_label( vgname, true, false, true ),
-		                2, 3, top++, bottom++, Gtk::FILL ) ;
+		// Volume Group
+		grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("Volume Group:")) + "</b>"),
+		             1, top, 1, 1);
+		grid->attach(*Utils::mk_label(vgname, true, false, true),
+		             2, top++, 1, 1);
 	}
 
 	//Optional, members of multi-device file systems
 	if ( filesystem_ptn.filesystem == FS_LVM2_PV ||
 	     filesystem_ptn.filesystem == FS_BTRFS      )
 	{
-		//Members
-		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Members:") ) + "</b>", true, false, false, 0.0 /* ALIGN_TOP */ ),
-		                1, 2, top, bottom, Gtk::FILL ) ;
+		// Members
+		grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("Members:")) + "</b>", true, false, false, Gtk::ALIGN_START),
+		             1, top, 1, 1);
 
 		std::vector<Glib::ustring> members ;
 		switch ( filesystem_ptn.filesystem )
@@ -461,21 +440,24 @@ void Dialog_Partition_Info::Display_Info()
 				break ;
 		}
 
-		table->attach( *Utils::mk_label( Glib::build_path( "\n", members ), true, false, true ),
-		               2, 3, top++, bottom++, Gtk::FILL );
+		grid->attach(*Utils::mk_label(Glib::build_path("\n", members), true, false, true),
+		              2, top++, 1, 1);
 	}
 
 	if ( filesystem_ptn.filesystem == FS_LVM2_PV )
 	{
-		//Logical Volumes
-		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Logical Volumes:") ) + "</b>", true, false, false, 0.0 /* ALIGN_TOP */ ),
-		                1, 2, top, bottom, Gtk::FILL );
+		// Logical Volumes
+		grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("Logical Volumes:")) + "</b>", true, false, false, Gtk::ALIGN_START),
+		             1, top, 1, 1);
 
 		std::vector<Glib::ustring> lvs = LVM2_PV_Info::get_vg_lvs( vgname );
-		table->attach( *Utils::mk_label( Glib::build_path( "\n", lvs ), true, false, true ),
-		               2, 3, top++, bottom++, Gtk::FILL );
+		grid->attach(*Utils::mk_label(Glib::build_path("\n", lvs), true, false, true),
+		             2, top++, 1, 1);
 	}
 
+	// Initialize grid top attach tracker (right side of the grid)
+	int topright = 1;
+
 	//Right field & value pair area
 	if ( partition .sector_usage_known() )
 	{
@@ -483,186 +465,136 @@ void Dialog_Partition_Info::Display_Info()
 		int percent_used, percent_unused, percent_unallocated ;
 		partition .get_usage_triple( 100, percent_used, percent_unused, percent_unallocated ) ;
 
-		//Used
-		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Used:") ) + "</b>" ),
-				3, 4,
-				topright, bottomright,
-				Gtk::FILL ) ;
-		table ->attach( * Utils::mk_label( Utils::format_size( partition .get_sectors_used(), partition .sector_size ), true, false, true ),
-				4, 5,
-				topright, bottomright,
-				Gtk::FILL ) ;
-		table ->attach( * Utils::mk_label( "( " + Utils::num_to_str( percent_used ) + "% )"),
-				5, 6,
-				topright++, bottomright++,
-				Gtk::FILL ) ;
+		// Used
+		grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("Used:")) + "</b>"),
+		             3, topright, 1, 1);
+		grid->attach(*Utils::mk_label(Utils::format_size(partition.get_sectors_used(), partition.sector_size), true, false, true),
+		             4, topright, 1, 1);
+		grid->attach(*Utils::mk_label("( " + Utils::num_to_str(percent_used) + "% )"),
+		             5, topright++, 1, 1);
 
-		//unused
-		table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Unused:") ) + "</b>" ),
-				3, 4,
-				topright, bottomright,
-				Gtk::FILL ) ;
-		table ->attach( * Utils::mk_label( Utils::format_size( partition .get_sectors_unused(), partition .sector_size ), true, false, true ),
-				4, 5,
-				topright, bottomright,
-				Gtk::FILL ) ;
-		table ->attach( * Utils::mk_label( "( " + Utils::num_to_str( percent_unused ) + "% )"),
-				5, 6,
-				topright++, bottomright++,
-				Gtk::FILL ) ;
+		// Unused
+		grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("Unused:")) + "</b>"),
+		             3, topright, 1, 1);
+		grid->attach(*Utils::mk_label(Utils::format_size(partition.get_sectors_unused(), partition.sector_size), true, false, true),
+		             4, topright, 1, 1);
+		grid->attach(*Utils::mk_label("( " + Utils::num_to_str(percent_unused) + "% )"),
+		             5, topright++, 1, 1);
 
 		//unallocated
 		Sector sectors_unallocated = partition .get_sectors_unallocated() ;
 		if ( sectors_unallocated > 0 )
 		{
-			table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Unallocated:") ) + "</b>" ),
-					3, 4,
-					topright, bottomright,
-					Gtk::FILL ) ;
-			table ->attach( * Utils::mk_label( Utils::format_size( sectors_unallocated, partition .sector_size ), true, false, true ),
-					4, 5,
-					topright, bottomright,
-					Gtk::FILL ) ;
-			table ->attach( * Utils::mk_label( "( " + Utils::num_to_str( percent_unallocated ) + "% )"),
-					5, 6,
-					topright++, bottomright++,
-					Gtk::FILL ) ;
+			grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("Unallocated:")) + "</b>"),
+			             3, topright, 1, 1);
+			grid->attach(*Utils::mk_label(Utils::format_size(sectors_unallocated, partition.sector_size), true, false, true),
+			             4, topright, 1, 1);
+			grid->attach(*Utils::mk_label("( " + Utils::num_to_str(percent_unallocated) + "% )"),
+			             5, topright++, 1, 1);
 		}
 	}
 
-	//size
-	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Size:") ) + "</b>" ),
-			3, 4,
-			topright, bottomright,
-			Gtk::FILL) ;
-	table ->attach( * Utils::mk_label( Utils::format_size( ptn_sectors, partition .sector_size ), true, false, true ),
-			4, 5,
-			topright++, bottomright++,
-			Gtk::FILL ) ;
+	// Size
+	grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("Size:")) + "</b>"),
+	             3, topright, 1, 1);
+	grid->attach(*Utils::mk_label(Utils::format_size(ptn_sectors, partition.sector_size), true, false, true),
+	             4, topright++, 1, 1);
 
 	//ensure left row tracker set to largest side (left/right)
 	top = std::max( top, topright );
-	bottom = std::max( bottom, bottomright );
 
-	//one blank line
-	table ->attach( * Utils::mk_label( "" ), 0, 6, top++, bottom++, Gtk::FILL ) ;
+	// One blank line
+	grid->attach(*Utils::mk_label(""), 0, top++, 6, 1);
 
 	if ( partition.filesystem == FS_LUKS )
 	{
 		// ENCRYPTION DETAIL SECTION
-		// encryption headline
-		table->attach( *Utils::mk_label( "<b>" + Glib::ustring( _("Encryption") ) + "</b>" ),
-		               0, 6, top++, bottom++, Gtk::FILL );
+		// Encryption headline
+		grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("Encryption")) + "</b>"),
+		             0, top++, 6, 1);
 
 		// Encryption
-		table->attach( *Utils::mk_label( "<b>" + Glib::ustring( _("Encryption:") ) + "</b>"),
-		               1, 2, top, bottom, Gtk::FILL);
-		table->attach( *Utils::mk_label( Utils::get_filesystem_string( partition.filesystem ), true, false, true ),
-		               2, 3, top++, bottom++, Gtk::FILL);
+		grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("Encryption:")) + "</b>"),
+		             1, top, 1, 1);
+		grid->attach(*Utils::mk_label(Utils::get_filesystem_string(partition.filesystem), true, false, true),
+		             2, top++, 1, 1);
 
 		// LUKS path
-		table->attach( *Utils::mk_label( "<b>" + Glib::ustring( _("Path:") ) + "</b>"),
-		               1, 2, top, bottom, Gtk::FILL);
+		grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("Path:")) + "</b>"),
+		             1, top, 1, 1);
 		if ( partition.busy )
-			table->attach( *Utils::mk_label( partition.get_mountpoint(), true, false, true ),
-			               2, 3, top, bottom, Gtk::FILL);
-		top++, bottom++;
+			grid->attach(*Utils::mk_label(partition.get_mountpoint(), true, false, true),
+			             2, top, 1, 1);
+		top++;
 
 		// LUKS uuid
-		table->attach( *Utils::mk_label( "<b>" + Glib::ustring( _("UUID:") ) + "</b>"),
-		               1, 2, top, bottom, Gtk::FILL);
-		table->attach( *Utils::mk_label( partition.uuid, true, false, true ),
-		               2, 3, top++, bottom++, Gtk::FILL);
+		grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("UUID:")) + "</b>"),
+		             1, top, 1, 1);
+		grid->attach(*Utils::mk_label(partition.uuid, true, false, true),
+		             2, top++, 1, 1);
 
 		// LUKS status
-		table->attach( *Utils::mk_label( "<b>" + Glib::ustring( _("Status:") ) + "</b>" ),
-		               1, 2, top, bottom, Gtk::FILL );
+		grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("Status:")) + "</b>"),
+		             1, top, 1, 1);
 		Glib::ustring str_temp;
 		if ( partition.busy )
 			str_temp = luks_open;
 		else
 			str_temp = luks_closed;
-		table->attach( *Utils::mk_label( str_temp, true, false, true ), 2, 3, top++, bottom++, Gtk::FILL );
+		grid->attach(*Utils::mk_label(str_temp, true, false, true), 2, top++, 1, 1);
 
-		// one blank line
-		table->attach( *Utils::mk_label( "" ), 0, 6, top++, bottom++, Gtk::FILL );
+		// One blank line
+		grid->attach(*Utils::mk_label(""), 0, top++, 6, 1);
 	}
 
-	//PARTITION DETAIL SECTION
-	//partition headline
-	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Partition") ) + "</b>" ),
-			0, 6,
-			top++, bottom++,
-			Gtk::FILL ) ;
+	// PARTITION DETAIL SECTION
+	// Partition headline
+	grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("Partition")) + "</b>"),
+	             0, top++, 6, 1);
 
 	//use current left row tracker position as anchor for right
 	topright = top ;
-	bottomright = bottom ;
 
-	//Left field & value pair area
-	//path
-	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Path:") ) + "</b>" ),
-			1, 2,
-			top, bottom,
-			Gtk::FILL ) ;
-	table->attach( * Utils::mk_label( partition.get_path(), true, false, true ),
-	               2, 3,
-	               top++, bottom++,
-	               Gtk::FILL );
+	// Left field & value pair area
+	// Path
+	grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("Path:")) + "</b>"),
+	             1, top, 1, 1);
+	grid->attach(*Utils::mk_label(partition.get_path(), true, false, true),
+	             2, top++, 1, 1);
 
 	if (partition.filesystem != FS_UNALLOCATED && partition.status != STAT_NEW)
 	{
-		// name
-		table->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Name:") ) + "</b>"),
-		               1, 2,
-		               top, bottom,
-		               Gtk::FILL );
-		table->attach( * Utils::mk_label( partition.name, true, false, true ),
-		               2, 3,
-		               top++, bottom++,
-		               Gtk::FILL );
+		// Name
+		grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("Name:")) + "</b>"),
+		             1, top, 1, 1);
+		grid->attach(*Utils::mk_label(partition.name, true, false, true),
+		             2, top++, 1, 1);
 
-		// flags
-		table->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Flags:") ) + "</b>" ),
-		               1, 2,
-		               top, bottom,
-		               Gtk::FILL );
-		table->attach( * Utils::mk_label( Glib::build_path( ", ", partition .flags ), true, false, true ),
-		               2, 3,
-		               top++, bottom++,
-		               Gtk::FILL );
+		// Flags
+		grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("Flags:")) + "</b>"),
+		             1, top, 1, 1);
+		grid->attach(*Utils::mk_label(Glib::build_path(", ", partition.flags), true, false, true),
+		             2, top++, 1, 1);
 	}
 
-	//Right field & value pair area
-	//first sector
-	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("First sector:") ) + "</b>" ),
-			3, 4,
-			topright, bottomright,
-			Gtk::FILL ) ;
-	table ->attach( * Utils::mk_label( Utils::num_to_str( partition .sector_start ), true, false, true ),
-			4, 5,
-			topright++, bottomright++,
-			Gtk::FILL ) ;
-	
-	//last sector
-	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Last sector:") ) + "</b>" ),
-			3, 4,
-			topright, bottomright,
-			Gtk::FILL ) ;
-	table ->attach( * Utils::mk_label( Utils::num_to_str( partition.sector_end ), true, false, true ),
-			4, 5,
-			topright++, bottomright++,
-			Gtk::FILL ) ; 
-	
-	//total sectors
-	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Total sectors:") ) + "</b>" ),
-			3, 4,
-			topright, bottomright,
-			Gtk::FILL ) ;
-	table ->attach( * Utils::mk_label( Utils::num_to_str( ptn_sectors ), true, false, true ),
-			4, 5,
-			topright++, bottomright++,
-			Gtk::FILL ) ;
+	// Right field & value pair area
+	// First sector
+	grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("First sector:")) + "</b>"),
+	              3, topright, 1, 1);
+	grid->attach(*Utils::mk_label(Utils::num_to_str(partition.sector_start), true, false, true),
+	              4, topright++, 1, 1);
+
+	// Last sector
+	grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("Last sector:")) + "</b>"),
+	             3, topright, 1, 1);
+	grid->attach(*Utils::mk_label(Utils::num_to_str(partition.sector_end), true, false, true),
+	             4, topright++, 1, 1);
+
+	// Total sectors
+	grid->attach(*Utils::mk_label("<b>" + Glib::ustring(_("Total sectors:")) + "</b>"),
+	             3, topright, 1, 1);
+	grid->attach(*Utils::mk_label(Utils::num_to_str(ptn_sectors), true, false, true),
+	             4, topright++, 1, 1);
 }
 
 Dialog_Partition_Info::~Dialog_Partition_Info()
