@@ -19,6 +19,9 @@
 #include "Dialog_Rescue_Data.h"
 #include "Partition.h"
 
+#include <glibmm/stringutils.h>
+#include <glibmm/shell.h>
+#include <gtk/gtk.h>
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/stock.h>
 #include <gtkmm/checkbutton.h>
@@ -50,7 +53,7 @@ void Dialog_Rescue_Data::draw_dialog()
 	Glib::ustring *message;
 
 	/*TO TRANSLATORS: looks like    File systems found on /dev/sdb */
-	this ->set_title( String::ucompose( _("File systems found on %1"), this->device_path ) );
+	this ->set_title( Glib::ustring::compose( _("File systems found on %1"), this->device_path ) );
 
 	message=new Glib::ustring("<big><b>");
 	if(!this->inconsistencies)
@@ -66,16 +69,15 @@ void Dialog_Rescue_Data::draw_dialog()
 		msg_label.append(_("You might encounter errors trying to view these file systems."));
 		
 		Gtk::Label *inconsis_label=manage(Utils::mk_label(msg_label));
-		Gdk::Color c( "red" );
-		inconsis_label->modify_fg(Gtk::STATE_NORMAL, c );
-		this->get_vbox()->pack_end(*inconsis_label, Gtk::PACK_SHRINK, 5);
+		inconsis_label->override_color(Gdk::RGBA("red"), Gtk::STATE_FLAG_NORMAL);
+		this->get_content_area()->pack_end(*inconsis_label, Gtk::PACK_SHRINK, 5);
 	}
 	message->append("</b></big>");
 
-	this->get_vbox()->set_spacing(5);
+	this->get_content_area()->set_spacing(5);
 
 	Gtk::Label *msgLbl=Utils::mk_label(*message);
-	this->get_vbox()->pack_start(*msgLbl, Gtk::PACK_SHRINK);
+	this->get_content_area()->pack_start(*msgLbl, Gtk::PACK_SHRINK);
 
 	this->create_list_of_fs();
 
@@ -83,14 +85,14 @@ void Dialog_Rescue_Data::draw_dialog()
 	info_txt+="\n";
 	info_txt+=_("All mounted views will be unmounted when you close this dialog.");
 
-	Gtk::HBox *infoBox=manage(new Gtk::HBox());
-	Gtk::Image *infoImg=manage(new Gtk::Image( Gtk::Stock::DIALOG_INFO, Gtk::ICON_SIZE_DIALOG));
+	Gtk::Box *infoBox = manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL));
+	Gtk::Image *infoImg = Utils::mk_image(Gtk::Stock::DIALOG_INFO, Gtk::ICON_SIZE_DIALOG);
 	Gtk::Label *infoLabel= manage(new Gtk::Label (info_txt));
 
 	infoBox->pack_start(*infoImg, Gtk::PACK_SHRINK, 5);
 	infoBox->pack_start(*infoLabel, Gtk::PACK_SHRINK);
 
-	this->get_vbox()->pack_start(*infoBox, Gtk::PACK_SHRINK);
+	this->get_content_area()->pack_start(*infoBox, Gtk::PACK_SHRINK);
 
 	this->show_all_children();
 
@@ -101,7 +103,7 @@ void Dialog_Rescue_Data::draw_dialog()
  * Create the list of the filesystems found */
 void Dialog_Rescue_Data::create_list_of_fs()
 {
-	Gtk::VBox *vb=manage(new Gtk::VBox());
+	Gtk::Box *vb = manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL));
 	vb->set_border_width(5);
 	vb->set_spacing(5);
 	this->frm=Gtk::manage(new Gtk::Frame(_("File systems")));
@@ -126,13 +128,13 @@ void Dialog_Rescue_Data::create_list_of_fs()
 		}
 
 		/*TO TRANSLATORS: looks like    1: ntfs (10240 MiB)*/
-		Gtk::Label *fsLbl= manage(new Gtk::Label( String::ucompose(_("#%1: %2 (%3 MiB)"), i+1, fs_name, (this->partitions[i].get_byte_length()/1024/1024))));
+		Gtk::Label *fsLbl= manage(new Gtk::Label( Glib::ustring::compose(_("#%1: %2 (%3 MiB)"), i+1, fs_name, (this->partitions[i].get_byte_length()/1024/1024))));
 		if(this->is_inconsistent(this->partitions[i]))
 		{
 			fsLbl->set_label(fsLbl->get_label().append(" (!)"));
 		}
 
-		Gtk::HBox *hb=manage(new Gtk::HBox());
+		Gtk::Box *hb = manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL));
 
 		Gtk::Button *btn=manage(new Gtk::Button(_("View")));
 
@@ -144,7 +146,7 @@ void Dialog_Rescue_Data::create_list_of_fs()
         vb->pack_start(*hb, Gtk::PACK_SHRINK);
 	}
 
-	this->get_vbox()->pack_start(*this->frm, Gtk::PACK_SHRINK);
+	this->get_content_area()->pack_start(*this->frm, Gtk::PACK_SHRINK);
 }
 
 /*
@@ -340,7 +342,7 @@ void Dialog_Rescue_Data::read_partitions_from_buffer()
 			part_num=Utils::convert_to_int(num);
 
 			//Get the part_path
-			part_path=String::ucompose ( "%1%2", this->device_path, num );
+			part_path=Glib::ustring::compose( "%1%2", this->device_path, num );
 
 			while(getline(*this->buffer, line))
 			{
