@@ -20,6 +20,8 @@
 #include "Utils.h"
 
 #include <glibmm/ustring.h>
+#include <glibmm/miscutils.h>
+#include <glibmm/shell.h>
 #include <vector>
 
 namespace GParted
@@ -54,6 +56,21 @@ void FS_Info::load_cache()
 	fs_info_cache_initialized = true;
 }
 
+void FS_Info::load_cache_for_paths( const std::vector<Glib::ustring> &device_paths )
+{
+	initialize_if_required();
+	const BlockSpecial empty_bs = BlockSpecial();
+	for ( unsigned int i = 0 ; i < device_paths.size() ; i ++ )
+	{
+		const FS_Entry & fs_entry = get_cache_entry_by_path( device_paths[i] );
+		if ( fs_entry.path == empty_bs )
+		{
+			// Run "blkid PATH" and load entry into cache for missing entries.
+			load_fs_info_cache_extra_for_path( device_paths[i] );
+		}
+	}
+}
+
 // Retrieve the file system type for the path
 Glib::ustring FS_Info::get_fs_type( const Glib::ustring & path )
 {
@@ -73,7 +90,8 @@ Glib::ustring FS_Info::get_fs_type( const Glib::ustring & path )
 			// bypassing the the cache to get the correct results.
 			Glib::ustring output;
 			Glib::ustring error;
-			if ( ! Utils::execute_command( "blkid -c /dev/null " + path, output, error, true ) )
+			if ( ! Utils::execute_command( "blkid -c /dev/null " + Glib::shell_quote( path ),
+			                               output, error, true )                              )
 				fs_sec_type = Utils::regexp_label( output, " SEC_TYPE=\"([^\"]*)\"" );
 		}
 		if ( fs_sec_type == "msdos" )
@@ -89,9 +107,27 @@ Glib::ustring FS_Info::get_fs_type( const Glib::ustring & path )
 Glib::ustring FS_Info::get_label( const Glib::ustring & path, bool & found )
 {
 	initialize_if_required();
-	const FS_Entry & fs_entry = get_cache_entry_by_path( path );
-	found = fs_entry.have_label;
-	return fs_entry.label;
+	BlockSpecial bs = BlockSpecial( path );
+	for ( unsigned int i = 0 ; i < fs_info_cache.size() ; i ++ )
+		if ( bs == fs_info_cache[i].path )
+		{
+			if ( fs_info_cache[i].have_label || fs_info_cache[i].type == "" )
+			{
+				// Already have the label or this is a blank cache entry
+				// for a whole disk device containing a partition table,
+				// so no label (as created by
+				// load_fs_info_cache_extra_for_path()).
+				found = fs_info_cache[i].have_label;
+				return fs_info_cache[i].label;
+			}
+
+			// Run blkid to get the label for this one partition, update the
+			// cache and return the found label.
+			found = run_blkid_update_cache_one_label( fs_info_cache[i] );
+			return fs_info_cache[i].label;
+		}
+	found = false;
+	return "";
 }
 
 // Retrieve the uuid given for the path
@@ -117,6 +153,7 @@ Glib::ustring FS_Info::get_path_by_uuid( const Glib::ustring & uuid )
 Glib::ustring FS_Info::get_path_by_label( const Glib::ustring & label )
 {
 	initialize_if_required();
+	update_fs_info_cache_all_labels();
 	for ( unsigned int i = 0 ; i < fs_info_cache.size() ; i ++ )
 		if ( label == fs_info_cache[i].label )
 			return fs_info_cache[i].path.m_name;
@@ -207,7 +244,8 @@ void FS_Info::load_fs_info_cache_extra_for_path( const Glib::ustring & path )
 bool FS_Info::run_blkid_load_cache( const Glib::ustring & path )
 {
 	// Parse blkid output line by line extracting mandatory field: path and optional
-	// fields: type, sec_type, uuid, label.
+	// fields: type, sec_type, uuid.  Label is not extracted here because of blkid's
+	// default non-reversible encoding of non printable ASCII bytes.
 	// Example output:
 	//     /dev/sda1: UUID="f828ee8c-1e16-4ca9-b234-e4949dcd4bd1" TYPE="xfs"
 	//     /dev/sda2: UUID="p31pR5-qPLm-YICz-O09i-sB4u-mAH2-GVSNWG" TYPE="LVM2_member"
@@ -219,7 +257,7 @@ bool FS_Info::run_blkid_load_cache( const Glib::ustring & path )
 	//     /dev/sdb3: PARTUUID="bb8438e1-d9f1-45d3-9888-e990b598900d"
 	Glib::ustring cmd = "blkid";
 	if ( path.size() )
-		cmd = cmd + " " + path;
+		cmd = cmd + " " + Glib::shell_quote( path );
 	Glib::ustring output;
 	Glib::ustring error;
 	bool loaded_entries = false;
@@ -238,11 +276,6 @@ bool FS_Info::run_blkid_load_cache( const Glib::ustring & path )
 				fs_entry.type = Utils::regexp_label( lines[i], " TYPE=\"([^\"]*)\"" );
 				fs_entry.sec_type = Utils::regexp_label( lines[i], " SEC_TYPE=\"([^\"]*)\"" );
 				fs_entry.uuid = Utils::regexp_label( lines[i], " UUID=\"([^\"]*)\"" );
-				if ( lines[i].find( " LABEL=\"" ) != Glib::ustring::npos )
-				{
-					fs_entry.have_label = true;
-					fs_entry.label = Utils::regexp_label( lines[i], " LABEL=\"([^\"]*)\"" );
-				}
 				fs_info_cache.push_back( fs_entry );
 				loaded_entries = true;
 			}
@@ -252,4 +285,44 @@ bool FS_Info::run_blkid_load_cache( const Glib::ustring & path )
 	return loaded_entries;
 }
 
+void FS_Info::update_fs_info_cache_all_labels()
+{
+	if ( ! blkid_found )
+		return;
+
+	// For all cache entries which are file systems but don't yet have a label load it
+	// now.
+	for ( unsigned int i = 0 ; i < fs_info_cache.size() ; i ++ )
+		if ( fs_info_cache[i].type != "" && ! fs_info_cache[i].have_label )
+			run_blkid_update_cache_one_label( fs_info_cache[i] );
+}
+
+bool FS_Info::run_blkid_update_cache_one_label( FS_Entry & fs_entry )
+{
+	if ( ! blkid_found )
+		return false;
+
+	// (#786502) Run a separate blkid execution for a single partition to get the
+	// label without blkid's default non-reversible encoding.
+	Glib::ustring output;
+	Glib::ustring error;
+	bool success = ! Utils::execute_command( "blkid -o value -s LABEL " + Glib::shell_quote( fs_entry.path.m_name ),
+	                                         output, error, true );
+	if ( ! success )
+		return false;
+
+	size_t len = output.length();
+	if ( len > 0 && output[len-1] == '\n' )
+	{
+		// Output is either the label with a terminating new line or zero bytes
+		// when the file system has no label.  Strip optional trailing new line
+		// from blkid output.
+		output.resize( len-1 );
+	}
+	// Update cache entry with the read label.
+	fs_entry.have_label = true;
+	fs_entry.label = output;
+	return true;
+}
+
 }//GParted
