@@ -19,11 +19,13 @@
 #include "Partition.h"
 #include "PartitionLUKS.h"
 #include "PartitionVector.h"
+#include "Utils.h"
 
 #include <vector>
 #include <gtkmm/cellrenderer.h>
 #include <gtkmm/cellrenderertext.h>
 #include <pangomm/layout.h>
+#include <glibmm/miscutils.h>
 #include <glibmm/ustring.h>
 
 namespace GParted
@@ -59,7 +61,7 @@ TreeView_Detail::TreeView_Detail()
 	// Color pixbuf cell is left aligned.
 	get_column(2)->get_first_cell()->property_xalign() = Gtk::ALIGN_START;
 	// File system text cell is left aligned.
-	std::vector<Gtk::CellRenderer*> renderers = get_column( 2 )->get_cell_renderers();
+	std::vector<Gtk::CellRenderer *> renderers = get_column(2)->get_cells();
 	Gtk::CellRendererText *cell_renderer_text = dynamic_cast<Gtk::CellRendererText*>( renderers.back() );
 	cell_renderer_text->property_xalign() = Gtk::ALIGN_START;
 
@@ -87,7 +89,9 @@ void TreeView_Detail::load_partitions( const PartitionVector & partitions )
 	bool show_mountpoints = false;
 	bool show_labels      = false;
 
+	block = true;
 	treestore_detail ->clear() ;
+	block = false;
 
 	load_partitions( partitions, show_names, show_mountpoints, show_labels );
 
@@ -158,16 +162,16 @@ void TreeView_Detail::create_row( const Gtk::TreeRow & treerow,
 	const Partition & filesystem_ptn = partition.get_filesystem_partition();
 	if ( filesystem_ptn.busy )
 		treerow[ treeview_detail_columns .icon1 ] = 
-			render_icon( Gtk::Stock::DIALOG_AUTHENTICATION, Gtk::ICON_SIZE_BUTTON );
-	
+			Utils::mk_pixbuf(*this, Gtk::Stock::DIALOG_AUTHENTICATION, Gtk::ICON_SIZE_BUTTON);
+
 	if ( partition.have_messages() > 0 )
 	{
 		if ( ! static_cast< Glib::RefPtr<Gdk::Pixbuf> >( treerow[ treeview_detail_columns .icon1 ] )  )
 			treerow[ treeview_detail_columns .icon1 ] = 
-				render_icon( Gtk::Stock::DIALOG_WARNING, Gtk::ICON_SIZE_BUTTON );
+				Utils::mk_pixbuf(*this, Gtk::Stock::DIALOG_WARNING, Gtk::ICON_SIZE_BUTTON);
 		else
 			treerow[ treeview_detail_columns .icon2 ] = 
-				render_icon( Gtk::Stock::DIALOG_WARNING, Gtk::ICON_SIZE_BUTTON );
+				Utils::mk_pixbuf(*this, Gtk::Stock::DIALOG_WARNING, Gtk::ICON_SIZE_BUTTON);
 	}
 
 	
